@@ -695,3 +695,18 @@ cmp 'pkg_cmp_summary -Oa  #20.9' \
 
 '
 
+pkg_cmp_summary -A sec src_summary21.txt src_summary22.txt |
+cmp 'pkg_cmp_summary -A  #21.1' \
+'3 pkg_summary-utils
+
+2 perl
+
+'
+
+pkg_cmp_summary -O ret src_summary21.txt src_summary22.txt |
+cmp 'pkg_cmp_summary -O  #21.2' \
+'3 pkg_summary-utils
+
+2 perl
+
+'
