@@ -7,6 +7,7 @@ hide_distfile_size (){
 }
 
 pkg_src_summary -f PKGNAME,PKGPATH -A databases/sqlite3 |
+pkg_grep_summary -v -t strlist PKGBASE 'readline ncurses pkg_install-info' |
 hide_distfile_size | normalize_version | grep -vE 'DEPENDS=' |
 cmp 'pkg_src_summary #27.1' \
 'PKGNAME=sqlite3-X
@@ -15,6 +16,7 @@ PKGPATH=databases/sqlite3
 '
 
 pkg_src_summary -f PKGNAME,PKGPATH -At databases/sqlite3 |
+pkg_grep_summary -v -t strlist PKGBASE 'readline ncurses pkg_install-info nbpatch' |
 hide_distfile_size | normalize_version | grep -vE 'DEPENDS=' |
 cmp 'pkg_src_summary #27.2' \
 'PKGNAME=sqlite3-X
@@ -136,7 +138,15 @@ PKGPATH=devel/subversion
 pkg_src_summary -m -f PKGNAME,PKGPATH devel/subversion:PKG_APACHE=apache2,PYTHON_VERSION_REQD=27 |
 normalize_version |
 cmp 'pkg_src_summary #23.6' \
-'ASSIGNMENTS=PKG_APACHE=apache2,RUBY_VERSION_REQD=18
+'ASSIGNMENTS=PKG_APACHE=apache2,RUBY_VERSION_REQD=200
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache2
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache2,RUBY_VERSION_REQD=18
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
@@ -159,7 +169,23 @@ PKGPATH=devel/subversion
 pkg_src_summary -m -f PKGNAME,PKGPATH devel/subversion:PYTHON_VERSION_REQD=26 |
 normalize_version |
 cmp 'pkg_src_summary #23.4' \
-'ASSIGNMENTS=PYTHON_VERSION_REQD=26,PKG_APACHE=apache13,RUBY_VERSION_REQD=18
+'ASSIGNMENTS=PYTHON_VERSION_REQD=26,PKG_APACHE=apache13,RUBY_VERSION_REQD=200
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=26,PKG_APACHE=apache13
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=26,PKG_APACHE=apache13,RUBY_VERSION_REQD=18
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=26,PKG_APACHE=apache2,RUBY_VERSION_REQD=200
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=26,PKG_APACHE=apache2
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
@@ -167,10 +193,26 @@ ASSIGNMENTS=PYTHON_VERSION_REQD=26,PKG_APACHE=apache2,RUBY_VERSION_REQD=18
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
+ASSIGNMENTS=PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=200
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=26
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
 ASSIGNMENTS=PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=18
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
+ASSIGNMENTS=PYTHON_VERSION_REQD=26,PKG_APACHE=apache24,RUBY_VERSION_REQD=200
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=26,PKG_APACHE=apache24
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
 ASSIGNMENTS=PYTHON_VERSION_REQD=26,PKG_APACHE=apache24,RUBY_VERSION_REQD=18
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
@@ -216,7 +258,23 @@ PKGPATH=devel/subversion
 pkg_src_summary -m -f PKGNAME,PKGPATH devel/subversion:PKG_APACHE=apache2 |
 normalize_version |
 cmp 'pkg_src_summary #23.2' \
-'ASSIGNMENTS=PKG_APACHE=apache2,RUBY_VERSION_REQD=18
+'ASSIGNMENTS=PKG_APACHE=apache2,RUBY_VERSION_REQD=200
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache2
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache2,RUBY_VERSION_REQD=18
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache2,PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=200
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache2,PYTHON_VERSION_REQD=26
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
@@ -229,7 +287,23 @@ PKGPATH=devel/subversion
 pkg_src_summary -m -f PKGNAME,PKGPATH devel/subversion |
 normalize_version |
 cmp 'pkg_src_summary #23.1' \
-'ASSIGNMENTS=PKG_APACHE=apache13,RUBY_VERSION_REQD=18
+'ASSIGNMENTS=PKG_APACHE=apache13,RUBY_VERSION_REQD=200
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache13
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache13,RUBY_VERSION_REQD=18
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache13,PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=200
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache13,PYTHON_VERSION_REQD=26
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
@@ -237,26 +311,73 @@ ASSIGNMENTS=PKG_APACHE=apache13,PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=18
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
+ASSIGNMENTS=PKG_APACHE=apache2,RUBY_VERSION_REQD=200
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache2
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
 ASSIGNMENTS=PKG_APACHE=apache2,RUBY_VERSION_REQD=18
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
+ASSIGNMENTS=PKG_APACHE=apache2,PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=200
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache2,PYTHON_VERSION_REQD=26
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
 ASSIGNMENTS=PKG_APACHE=apache2,PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=18
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
+ASSIGNMENTS=RUBY_VERSION_REQD=200
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
 ASSIGNMENTS=RUBY_VERSION_REQD=18
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
+ASSIGNMENTS=PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=200
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=26
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
 ASSIGNMENTS=PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=18
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
+ASSIGNMENTS=PKG_APACHE=apache24,RUBY_VERSION_REQD=200
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache24
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
 ASSIGNMENTS=PKG_APACHE=apache24,RUBY_VERSION_REQD=18
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
+ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=200
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=26
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
 ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=18
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
@@ -279,6 +400,10 @@ cmp 'pkg_src_summary #22.2' \
 PKGNAME=ap2-php54-X
 PKGPATH=www/ap-php
 
+ASSIGNMENTS=PKG_APACHE=apache2,PHP_VERSION_REQD=55
+PKGNAME=ap2-php55-X
+PKGPATH=www/ap-php
+
 ASSIGNMENTS=PKG_APACHE=apache2,PHP_VERSION_REQD=53
 PKGNAME=ap2-php53-X
 PKGPATH=www/ap-php
@@ -292,6 +417,10 @@ cmp 'pkg_src_summary #22.1' \
 PKGNAME=ap13-php54-X
 PKGPATH=www/ap-php
 
+ASSIGNMENTS=PKG_APACHE=apache13,PHP_VERSION_REQD=55
+PKGNAME=ap13-php55-X
+PKGPATH=www/ap-php
+
 ASSIGNMENTS=PKG_APACHE=apache13,PHP_VERSION_REQD=53
 PKGNAME=ap13-php53-X
 PKGPATH=www/ap-php
@@ -300,6 +429,10 @@ ASSIGNMENTS=PKG_APACHE=apache2
 PKGNAME=ap2-php54-X
 PKGPATH=www/ap-php
 
+ASSIGNMENTS=PKG_APACHE=apache2,PHP_VERSION_REQD=55
+PKGNAME=ap2-php55-X
+PKGPATH=www/ap-php
+
 ASSIGNMENTS=PKG_APACHE=apache2,PHP_VERSION_REQD=53
 PKGNAME=ap2-php53-X
 PKGPATH=www/ap-php
@@ -307,6 +440,10 @@ PKGPATH=www/ap-php
 PKGNAME=ap22-php54-X
 PKGPATH=www/ap-php
 
+ASSIGNMENTS=PHP_VERSION_REQD=55
+PKGNAME=ap22-php55-X
+PKGPATH=www/ap-php
+
 ASSIGNMENTS=PHP_VERSION_REQD=53
 PKGNAME=ap22-php53-X
 PKGPATH=www/ap-php
@@ -315,6 +452,10 @@ ASSIGNMENTS=PKG_APACHE=apache24
 PKGNAME=ap24-php54-X
 PKGPATH=www/ap-php
 
+ASSIGNMENTS=PKG_APACHE=apache24,PHP_VERSION_REQD=55
+PKGNAME=ap24-php55-X
+PKGPATH=www/ap-php
+
 ASSIGNMENTS=PKG_APACHE=apache24,PHP_VERSION_REQD=53
 PKGNAME=ap24-php53-X
 PKGPATH=www/ap-php
